afaq-dl
========

Download the online book [An Anarchist FAQ (AFAQ)]
(http://www.anarchism.pageabode.com/afaq/index.html),
convert the HTML to Markdown and push the changes to the [afaq]
(https://0xacab/ju/afaq) repository.

The files in the `afaq` repository are used as the `upstream` for the
Debian [anarchism]
(https://packages.debian.org/jessie/anarchism) package..

Please see the [README.md]
(https://0xacab.org/ju/afaq/blob/master/README.md) in the `afaq`
repository for more details.

Install
--------

See [INSTALL.md]

Download
--------

You can download this project in either
[zip](http://0xacab.org/ju/afaq-dl/zipball/master()) or
[tar](http://0xacab.org/ju/afaq-dl/tarball/master) formats.

You can also clone the project with Git by running:

   git clone https://0xacab.org/ju/afaq-dl

Bugs and features
-----------------

If you wish to signal a bug or report a feature request, please fill-in
an issue on the [issue tracker](https://0xacab.org/ju/afaq-dl/issues).

License
--------
GPLv3

Copyright
----------
2016-2017 juxor <ju at riseup dot net>
